@@ -57,6 +57,7 @@ options.add_argument("--headless")
 chrome_options = webdriver.ChromeOptions()
 chrome_options.add_argument("--headless")
 chrome_options.add_argument("--disable-gpu")
+chrome_options.add_argument("--no-sandbox")
 #browser = webdriver.Firefox(executable_path="/users/krv/driver/geckodriver", options=options)
 
 ###################################################################################################################
@@ -673,7 +674,7 @@ def trends_google_play(gl, hl):
         browser = webdriver.Firefox(service = FirefoxService(GeckoDriverManager().install()), options=options)
     except Exception as e:
         print ("Використовую ядро Chromium!")
-        browser = webdriver.Chrome(service=ChromeService(ChromeDriverManager().install()), options=chrome_options)
+        browser = webdriver.Chrome(options=chrome_options)
     browser.implicitly_wait(10)
     browser.maximize_window()
 
